# jekyll-pygments-themes

A set of CSS theme files for Pygments (Python-based code highlighting tool)
created from the original built-in Pygments styles, ready for use with Jekyll.

## Theme Previews and Custom Theme Builder
- <https://jwarby.github.io/jekyll-pygments-themes>

## Using Themes Without Jekyll
If you want to use the themes with something other than Jekyll, you may need to
remove or change the CSS style prefix of `.highlight`.

## Links

- [Jekyll](http://jekyllrb.com/) ([direct link to code highlighting documentation](http://jekyllrb.com/docs/templates/#code-snippet-highlighting))
- [Pygments](http://pygments.org)

## Hacking

If you want to hack on the site, check out the [gh-pages](https://github.com/jwarby/jekyll-pygments-themes/tree/gh-pages) branch.

## Acknowledgements
Forked from [richleland/pygments-css](https://github.com/richleland/pygments-css).
